# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/stats/team_stats.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...api.stats import stats_pb2
from ...api.stats import per_possession_stats_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/stats/team_stats.proto',
  package='api.stats',
  serialized_pb=_b('\n\x1a\x61pi/stats/team_stats.proto\x12\tapi.stats\x1a\x15\x61pi/stats/stats.proto\x1a$api/stats/per_possession_stats.proto\"\xcc\x01\n\x0c\x43\x65nterOfMass\x12>\n\x15positional_tendencies\x18\x01 \x01(\x0b\x32\x1f.api.stats.PositionalTendencies\x12$\n\x1c\x61verage_distance_from_center\x18\x02 \x01(\x02\x12(\n average_max_distance_from_center\x18\x03 \x01(\x02\x12\x14\n\x0ctime_clumped\x18\x04 \x01(\x02\x12\x16\n\x0etime_boondocks\x18\x05 \x01(\x02\"\xce\x01\n\tTeamStats\x12)\n\npossession\x18\x01 \x01(\x0b\x32\x15.api.stats.Possession\x12(\n\nhit_counts\x18\x02 \x01(\x0b\x32\x14.api.stats.HitCounts\x12/\n\x0e\x63\x65nter_of_mass\x18\x03 \x01(\x0b\x32\x17.api.stats.CenterOfMass\x12;\n\x14per_possession_stats\x18\x04 \x01(\x0b\x32\x1d.api.stats.PerPossessionStats')
  ,
  dependencies=[stats_pb2.DESCRIPTOR,per_possession_stats_pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CENTEROFMASS = _descriptor.Descriptor(
  name='CenterOfMass',
  full_name='api.stats.CenterOfMass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positional_tendencies', full_name='api.stats.CenterOfMass.positional_tendencies', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_distance_from_center', full_name='api.stats.CenterOfMass.average_distance_from_center', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='average_max_distance_from_center', full_name='api.stats.CenterOfMass.average_max_distance_from_center', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_clumped', full_name='api.stats.CenterOfMass.time_clumped', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_boondocks', full_name='api.stats.CenterOfMass.time_boondocks', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=307,
)


_TEAMSTATS = _descriptor.Descriptor(
  name='TeamStats',
  full_name='api.stats.TeamStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='possession', full_name='api.stats.TeamStats.possession', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hit_counts', full_name='api.stats.TeamStats.hit_counts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='center_of_mass', full_name='api.stats.TeamStats.center_of_mass', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='per_possession_stats', full_name='api.stats.TeamStats.per_possession_stats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=516,
)

_CENTEROFMASS.fields_by_name['positional_tendencies'].message_type = stats_pb2._POSITIONALTENDENCIES
_TEAMSTATS.fields_by_name['possession'].message_type = stats_pb2._POSSESSION
_TEAMSTATS.fields_by_name['hit_counts'].message_type = stats_pb2._HITCOUNTS
_TEAMSTATS.fields_by_name['center_of_mass'].message_type = _CENTEROFMASS
_TEAMSTATS.fields_by_name['per_possession_stats'].message_type = per_possession_stats_pb2._PERPOSSESSIONSTATS
DESCRIPTOR.message_types_by_name['CenterOfMass'] = _CENTEROFMASS
DESCRIPTOR.message_types_by_name['TeamStats'] = _TEAMSTATS

CenterOfMass = _reflection.GeneratedProtocolMessageType('CenterOfMass', (_message.Message,), dict(
  DESCRIPTOR = _CENTEROFMASS,
  __module__ = 'api.stats.team_stats_pb2'
  # @@protoc_insertion_point(class_scope:api.stats.CenterOfMass)
  ))
_sym_db.RegisterMessage(CenterOfMass)

TeamStats = _reflection.GeneratedProtocolMessageType('TeamStats', (_message.Message,), dict(
  DESCRIPTOR = _TEAMSTATS,
  __module__ = 'api.stats.team_stats_pb2'
  # @@protoc_insertion_point(class_scope:api.stats.TeamStats)
  ))
_sym_db.RegisterMessage(TeamStats)


# @@protoc_insertion_point(module_scope)
