# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/metadata/player_loadout.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/metadata/player_loadout.proto',
  package='api.metadata',
  serialized_pb=_b('\n!api/metadata/player_loadout.proto\x12\x0c\x61pi.metadata\"\xdd\x01\n\rPlayerLoadout\x12\x13\n\x0bload_out_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x62\x61nner\x18\x02 \x01(\x05\x12\r\n\x05\x62oost\x18\x03 \x01(\x05\x12\x0b\n\x03\x63\x61r\x18\x04 \x01(\x05\x12\x16\n\x0egoal_explosion\x18\x05 \x01(\x05\x12\x0c\n\x04skin\x18\x06 \x01(\x05\x12\r\n\x05trail\x18\x07 \x01(\x05\x12\x0e\n\x06wheels\x18\x08 \x01(\x05\x12\x0f\n\x07version\x18\t \x01(\x05\x12\x0e\n\x06topper\x18\n \x01(\x05\x12\x0f\n\x07\x61ntenna\x18\x0b \x01(\x05\x12\x14\n\x0c\x65ngine_audio\x18\x0c \x01(\x05')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PLAYERLOADOUT = _descriptor.Descriptor(
  name='PlayerLoadout',
  full_name='api.metadata.PlayerLoadout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_out_id', full_name='api.metadata.PlayerLoadout.load_out_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner', full_name='api.metadata.PlayerLoadout.banner', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='boost', full_name='api.metadata.PlayerLoadout.boost', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='car', full_name='api.metadata.PlayerLoadout.car', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goal_explosion', full_name='api.metadata.PlayerLoadout.goal_explosion', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skin', full_name='api.metadata.PlayerLoadout.skin', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trail', full_name='api.metadata.PlayerLoadout.trail', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wheels', full_name='api.metadata.PlayerLoadout.wheels', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='api.metadata.PlayerLoadout.version', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topper', full_name='api.metadata.PlayerLoadout.topper', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='antenna', full_name='api.metadata.PlayerLoadout.antenna', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='engine_audio', full_name='api.metadata.PlayerLoadout.engine_audio', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=273,
)

DESCRIPTOR.message_types_by_name['PlayerLoadout'] = _PLAYERLOADOUT

PlayerLoadout = _reflection.GeneratedProtocolMessageType('PlayerLoadout', (_message.Message,), dict(
  DESCRIPTOR = _PLAYERLOADOUT,
  __module__ = 'api.metadata.player_loadout_pb2'
  # @@protoc_insertion_point(class_scope:api.metadata.PlayerLoadout)
  ))
_sym_db.RegisterMessage(PlayerLoadout)


# @@protoc_insertion_point(module_scope)
