# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/metadata/camera_settings.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/metadata/camera_settings.proto',
  package='api.metadata',
  serialized_pb=_b('\n\"api/metadata/camera_settings.proto\x12\x0c\x61pi.metadata\"\xa7\x01\n\x0e\x43\x61meraSettings\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\tstiffness\x18\x02 \x01(\x02\x12\x0e\n\x06height\x18\x03 \x01(\x02\x12\x18\n\x10transition_speed\x18\x04 \x01(\x02\x12\r\n\x05pitch\x18\x05 \x01(\x02\x12\x14\n\x0cswivel_speed\x18\x06 \x01(\x02\x12\x15\n\rfield_of_view\x18\x07 \x01(\x02\x12\x10\n\x08\x64istance\x18\x08 \x01(\x02')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CAMERASETTINGS = _descriptor.Descriptor(
  name='CameraSettings',
  full_name='api.metadata.CameraSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.metadata.CameraSettings.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stiffness', full_name='api.metadata.CameraSettings.stiffness', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='api.metadata.CameraSettings.height', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='transition_speed', full_name='api.metadata.CameraSettings.transition_speed', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='api.metadata.CameraSettings.pitch', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='swivel_speed', full_name='api.metadata.CameraSettings.swivel_speed', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='field_of_view', full_name='api.metadata.CameraSettings.field_of_view', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='distance', full_name='api.metadata.CameraSettings.distance', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=220,
)

DESCRIPTOR.message_types_by_name['CameraSettings'] = _CAMERASETTINGS

CameraSettings = _reflection.GeneratedProtocolMessageType('CameraSettings', (_message.Message,), dict(
  DESCRIPTOR = _CAMERASETTINGS,
  __module__ = 'api.metadata.camera_settings_pb2'
  # @@protoc_insertion_point(class_scope:api.metadata.CameraSettings)
  ))
_sym_db.RegisterMessage(CameraSettings)


# @@protoc_insertion_point(module_scope)
