# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/player.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..api.metadata import player_loadout_pb2
from ..api.metadata import camera_settings_pb2
from ..api.stats import player_stats_pb2
from ..api import player_id_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/player.proto',
  package='api',
  serialized_pb=_b('\n\x10\x61pi/player.proto\x12\x03\x61pi\x1a!api/metadata/player_loadout.proto\x1a\"api/metadata/camera_settings.proto\x1a\x1c\x61pi/stats/player_stats.proto\x1a\x13\x61pi/player_id.proto\"\x97\x03\n\x06Player\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.api.PlayerId\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08title_id\x18\x03 \x01(\x05\x12\r\n\x05score\x18\x04 \x01(\x05\x12\r\n\x05goals\x18\x05 \x01(\x05\x12\x0f\n\x07\x61ssists\x18\x06 \x01(\x05\x12\r\n\x05saves\x18\x07 \x01(\x05\x12\r\n\x05shots\x18\x08 \x01(\x05\x12\x35\n\x0f\x63\x61mera_settings\x18\t \x01(\x0b\x32\x1c.api.metadata.CameraSettings\x12,\n\x07loadout\x18\n \x01(\x0b\x32\x1b.api.metadata.PlayerLoadout\x12\x11\n\tis_orange\x18\x0b \x01(\x05\x12%\n\x05stats\x18\x0c \x01(\x0b\x32\x16.api.stats.PlayerStats\x12#\n\x0cparty_leader\x18\r \x01(\x0b\x32\r.api.PlayerId\x12\x0e\n\x06is_bot\x18\x0e \x01(\x08\x12\x14\n\x0ctime_in_game\x18\x0f \x01(\x02\x12\x1b\n\x13\x66irst_frame_in_game\x18\x10 \x01(\x05')
  ,
  dependencies=[player_loadout_pb2.DESCRIPTOR,camera_settings_pb2.DESCRIPTOR,player_stats_pb2.DESCRIPTOR,player_id_pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PLAYER = _descriptor.Descriptor(
  name='Player',
  full_name='api.Player',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='api.Player.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='api.Player.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title_id', full_name='api.Player.title_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score', full_name='api.Player.score', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='goals', full_name='api.Player.goals', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='assists', full_name='api.Player.assists', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='saves', full_name='api.Player.saves', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shots', full_name='api.Player.shots', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='camera_settings', full_name='api.Player.camera_settings', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loadout', full_name='api.Player.loadout', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_orange', full_name='api.Player.is_orange', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='api.Player.stats', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='party_leader', full_name='api.Player.party_leader', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_bot', full_name='api.Player.is_bot', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_in_game', full_name='api.Player.time_in_game', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_frame_in_game', full_name='api.Player.first_frame_in_game', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=555,
)

_PLAYER.fields_by_name['id'].message_type = player_id_pb2._PLAYERID
_PLAYER.fields_by_name['camera_settings'].message_type = camera_settings_pb2._CAMERASETTINGS
_PLAYER.fields_by_name['loadout'].message_type = player_loadout_pb2._PLAYERLOADOUT
_PLAYER.fields_by_name['stats'].message_type = player_stats_pb2._PLAYERSTATS
_PLAYER.fields_by_name['party_leader'].message_type = player_id_pb2._PLAYERID
DESCRIPTOR.message_types_by_name['Player'] = _PLAYER

Player = _reflection.GeneratedProtocolMessageType('Player', (_message.Message,), dict(
  DESCRIPTOR = _PLAYER,
  __module__ = 'api.player_pb2'
  # @@protoc_insertion_point(class_scope:api.Player)
  ))
_sym_db.RegisterMessage(Player)


# @@protoc_insertion_point(module_scope)
