# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/game.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..api.metadata import game_metadata_pb2
from ..api.metadata import mutators_pb2
from ..api.stats import game_stats_pb2
from ..api import player_pb2
from ..api import team_pb2
from ..api import party_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/game.proto',
  package='api',
  serialized_pb=_b('\n\x0e\x61pi/game.proto\x12\x03\x61pi\x1a api/metadata/game_metadata.proto\x1a\x1b\x61pi/metadata/mutators.proto\x1a\x1a\x61pi/stats/game_stats.proto\x1a\x10\x61pi/player.proto\x1a\x0e\x61pi/team.proto\x1a\x0f\x61pi/party.proto\"\xfa\x01\n\x04Game\x12\x31\n\rgame_metadata\x18\x01 \x01(\x0b\x32\x1a.api.metadata.GameMetadata\x12\x1c\n\x07players\x18\x02 \x03(\x0b\x32\x0b.api.Player\x12\x18\n\x05teams\x18\x03 \x03(\x0b\x32\t.api.Team\x12(\n\ngame_stats\x18\x04 \x01(\x0b\x32\x14.api.stats.GameStats\x12\x1b\n\x07parties\x18\x05 \x03(\x0b\x32\n.api.Party\x12\x0f\n\x07version\x18\x06 \x01(\x05\x12(\n\x08mutators\x18\x07 \x01(\x0b\x32\x16.api.metadata.Mutators*\x05\x08\x64\x10\xc8\x01')
  ,
  dependencies=[game_metadata_pb2.DESCRIPTOR,mutators_pb2.DESCRIPTOR,game_stats_pb2.DESCRIPTOR,player_pb2.DESCRIPTOR,team_pb2.DESCRIPTOR,party_pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='api.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='game_metadata', full_name='api.Game.game_metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='players', full_name='api.Game.players', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='teams', full_name='api.Game.teams', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_stats', full_name='api.Game.game_stats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parties', full_name='api.Game.parties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='api.Game.version', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mutators', full_name='api.Game.mutators', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=True,
  extension_ranges=[(100, 200), ],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=416,
)

_GAME.fields_by_name['game_metadata'].message_type = game_metadata_pb2._GAMEMETADATA
_GAME.fields_by_name['players'].message_type = player_pb2._PLAYER
_GAME.fields_by_name['teams'].message_type = team_pb2._TEAM
_GAME.fields_by_name['game_stats'].message_type = game_stats_pb2._GAMESTATS
_GAME.fields_by_name['parties'].message_type = party_pb2._PARTY
_GAME.fields_by_name['mutators'].message_type = mutators_pb2._MUTATORS
DESCRIPTOR.message_types_by_name['Game'] = _GAME

Game = _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), dict(
  DESCRIPTOR = _GAME,
  __module__ = 'api.game_pb2'
  # @@protoc_insertion_point(class_scope:api.Game)
  ))
_sym_db.RegisterMessage(Game)


# @@protoc_insertion_point(module_scope)
